@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-#$URL: https://rst2pdf.googlecode.com/svn/tags/0.92/rst2pdf/createpdf.py $
-#$Date: 2012-05-25 09:56:14 -0300 (Fri, 25 May 2012) $
-#$Revision: 2497 $
+#$URL: https://rst2pdf.googlecode.com/svn/tags/0.93/rst2pdf/createpdf.py $
+#$Date: 2012-12-14 18:05:04 -0300 (Fri, 14 Dec 2012) $
+#$Revision: 2624 $
 
 # See LICENSE.txt for licensing terms
 
@@ -143,16 +143,19 @@ class RstToPdf(object):
                  basedir=os.getcwd(),
                  splittables=False,
                  blank_first_page=False,
+                 first_page_on_right=False,
                  breakside='odd',
                  custom_cover='cover.tmpl',
                  floating_images=False,
                  numbered_links=False,
                  section_header_depth=2,
-                 raw_html=False
+                 raw_html=False,
+                 strip_elements_with_classes=[]
                  ):
         self.debugLinesPdf=False
         self.depth=0
         self.breakside=breakside
+        self.first_page_on_right=first_page_on_right
         self.blank_first_page=blank_first_page
         self.splittables=splittables
         self.basedir=basedir
@@ -203,6 +206,7 @@ class RstToPdf(object):
         self.section_header_depth = section_header_depth
         self.img_dir = os.path.join(self.PATH, 'images')
         self.raw_html = raw_html
+        self.strip_elements_with_classes = strip_elements_with_classes
 
         # Sorry about this, but importing sphinx.roles makes some
         # ordinary documents fail (demo.txt specifically) so
@@ -216,6 +220,7 @@ class RstToPdf(object):
         else:
             # These rst2pdf extensions conflict with sphinx
             directives.register_directive('code-block', pygments_code_block_directive.code_block_directive)
+            directives.register_directive('code', pygments_code_block_directive.code_block_directive)
             import math_directive
             self.gen_pdftext, self.gen_elements = nodehandlers(self)
 
@@ -444,7 +449,7 @@ class RstToPdf(object):
         #from pudb import set_trace; set_trace()
 
         for y in range(0, len(rows)):
-            for x in range(0, len(rows[y])):
+            for x in range(len(rows[y])-1, -1, -1):
                 cell = rows[y][x]
                 if isinstance(cell, str):
                     continue
@@ -529,16 +534,18 @@ class RstToPdf(object):
                     settings_overrides={'language_code': self.docutils_language}
                 else:
                     settings_overrides={}
+                settings_overrides['strip_elements_with_classes']=self.strip_elements_with_classes
                 self.doctree = docutils.core.publish_doctree(text,
                     source_path=source_path,
                     settings_overrides=settings_overrides)
+                #import pdb; pdb.set_trace()
                 log.debug(self.doctree)
             else:
                 log.error('Error: createPdf needs a text or a doctree')
                 return
         else:
             self.doctree = doctree
-
+            
         if self.numbered_links:
             # Transform all links to sections so they show numbers
             from sectnumlinks import SectNumFolder, SectRefExpander
@@ -546,7 +553,11 @@ class RstToPdf(object):
             self.doctree.walk(snf)
             srf = SectRefExpander(self.doctree, snf.sectnums)
             self.doctree.walk(srf)
-
+        if self.strip_elements_with_classes:
+            from docutils.transforms.universal import StripClassesAndElements
+            sce = StripClassesAndElements(self.doctree)
+            sce.apply()
+            
         elements = self.gen_elements(self.doctree)
 
         # Find cover template, save it in cover_file
@@ -665,6 +676,7 @@ class RstToPdf(object):
                         elif getattr(e, '_atTop', False) or isinstance(
                                 e, (UnhappyOnce, MyPageBreak)):
                             if fnPile:
+                                fnPile.insert(0, Separation())
                                 newStory.append(Sinker(fnPile))
                             newStory.append(e)
                             fnPile=[]
@@ -900,6 +912,8 @@ class HeaderOrFooter(object):
                     text = unicode(text, e.encoding)
                 except AttributeError:
                     text = unicode(text, 'utf-8')
+                except TypeError:
+                    text = unicode(text, 'utf-8')
 
             text = text.replace(u'###Page###', pnum)
             if '###Total###' in text:
@@ -914,6 +928,7 @@ class HeaderOrFooter(object):
             return text
 
         for i,e  in enumerate(elems):
+            # TODO: implement a search/replace for arbitrary things
             if isinstance(e, Paragraph):
                 text = replace(e.text)
                 elems[i] = Paragraph(text, e.style)
@@ -927,6 +942,12 @@ class HeaderOrFooter(object):
                             row[r]=self.replaceTokens([cell,], canv, doc, smarty)[0]
                 elems[i]=DelayedTable(data, e._colWidths, e.style)
 
+            elif isinstance(e, BoundByWidth):
+                for index, item in enumerate(e.content):
+                    if isinstance(item, Paragraph):
+                        e.content[index] = Paragraph(replace(item.text), item.style)
+                elems[i] = e
+
             elif isinstance(e, OddEven):
                 odd=self.replaceTokens([e.odd,], canv, doc, smarty)[0]
                 even=self.replaceTokens([e.even,], canv, doc, smarty)[0]
@@ -1008,6 +1029,16 @@ class FancyPage(PageTemplate):
         bg, x, y = info
         bg.drawOn(canv, x, y)
 
+    def is_left(self, page_num):
+        """Default behavior is that the first page is on the left.   
+           
+           If the user has --first_page_on_right, the calculation is reversed.
+        """
+        val = page_num % 2 == 1
+        if self.client.first_page_on_right:
+            val = not val
+        return val
+
 
     def beforeDrawPage(self, canv, doc):
         """Do adjustments to the page according to where we are in the document.
@@ -1050,7 +1081,7 @@ class FancyPage(PageTemplate):
                     - self.fh - styles.ts - styles.bs
 
         # Adjust gutter margins
-        if doc.page % 2: # Left page
+        if self.is_left(doc.page): # Left page
             x1 = styles.lm
         else: # Right page
             x1 = styles.lm + styles.gm
@@ -1079,7 +1110,7 @@ class FancyPage(PageTemplate):
         canv.addPageLabel(canv._pageNumber-1,numberingstyles[_counterStyle],_counter)
 
         log.info('Page %s [%s]'%(_counter,doc.page))
-        if doc.page % 2: # Left page
+        if self.is_left(doc.page): # Left page
             hx = self.hx
             fx = self.fx
         else: # Right Page
@@ -1258,17 +1289,16 @@ def parse_commandline():
         help='Maximum section level that starts in a new page.'
             ' Default: %d' % def_break)
 
-    def_fpeven = config.getValue("general", "first_page_even", False)
-    parser.add_option('--first-page-even', dest='first_page_even',
-        action='store_true', default=def_fpeven,
-        help='Whether first page is odd (as in the screen on "facing pages"),'
-            ' or even (as in a book).')
-
     def_blankfirst = config.getValue("general", "blank_first_page", False)
     parser.add_option('--blank-first-page', dest='blank_first_page',
         action='store_true', default=def_blankfirst,
         help='Add a blank page at the beginning of the document.')
 
+    def_first_page_on_right = config.getValue("general", "first_page_on_right", False)
+    parser.add_option('--first-page-on-right', dest='first_page_on_right',
+        action='store_true', default=def_first_page_on_right,
+        help='Two-sided book style (where first page starts on the right side)')
+
     def_breakside = config.getValue("general", "break_side", 'any')
     parser.add_option('--break-side', dest='breakside', metavar='VALUE',
         default=def_breakside,
@@ -1302,6 +1332,9 @@ def parse_commandline():
     parser.add_option('--use-numbered-links', action='store_true', default=def_numbered_links,
         help='When using numbered sections, adds the numbers to all links referring to the section headers. Default: %s'%def_numbered_links,
         dest='numbered_links')
+        
+    parser.add_option('--strip-elements-with-class', action='append', dest='strip_elements_with_classes',
+        metavar='CLASS', help='Remove elements with this CLASS from the output. Can be used multiple times.')
 
     return parser
 
@@ -1345,7 +1378,18 @@ def main(_args=None):
 
     filename = False
 
-    if len(args) == 0 or args[0] == '-':
+    if len(args) == 0:
+        args = [ '-', ]
+    elif len(args) > 2:
+        log.critical('Usage: %s [ file.txt [ file.pdf ] ]', sys.argv[0])
+        sys.exit(1)
+    elif len(args) == 2:
+        if options.output:
+            log.critical('You may not give both "-o/--output" and second argument')
+            sys.exit(1)
+        options.output = args.pop()
+
+    if args[0] == '-':
         infile = sys.stdin
         options.basedir=os.getcwd()
     elif len(args) > 1:
@@ -1437,12 +1481,14 @@ def main(_args=None):
         show_frame=options.show_frame,
         splittables=options.splittables,
         blank_first_page=options.blank_first_page,
+        first_page_on_right=options.first_page_on_right,
         breakside=options.breakside,
         custom_cover=options.custom_cover,
         floating_images=options.floating_images,
         numbered_links=options.numbered_links,
         raw_html=options.raw_html,
 	    section_header_depth=int(options.section_header_depth),
+	    strip_elements_with_classes=options.strip_elements_with_classes,
         ).createPdf(text=options.infile.read(),
                     source_path=options.infile.name,
                     output=options.outfile,
