@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 # See LICENSE.txt for licensing terms
-#$URL: https://rst2pdf.googlecode.com/svn/tags/0.92/rst2pdf/flowables.py $
-#$Date: 2012-02-28 21:07:21 -0300 (Tue, 28 Feb 2012) $
-#$Revision: 2443 $
+#$URL: https://rst2pdf.googlecode.com/svn/tags/0.93/rst2pdf/flowables.py $
+#$Date: 2012-12-06 10:59:55 -0300 (Thu, 06 Dec 2012) $
+#$Revision: 2540 $
 
 __docformat__ = 'reStructuredText'
 
@@ -190,9 +190,16 @@ class DelayedTable(Table):
 
     """
 
-    def __init__(self, data, colWidths, style, repeatrows=False, splitByRow=True):
+    def __init__(self, data, colWidths, style=None, repeatrows=False, splitByRow=True):
         self.data = data
         self._colWidths = colWidths
+        if style is None:
+            style = TableStyle([
+                ('LEFTPADDING', (0,0), (-1,-1), 0),
+                ('RIGHTPADDING', (0,0), (-1,-1), 0),
+                ('TOPPADDING', (0,0), (-1,-1), 0),
+                ('BOTTOMPADDING', (0,0), (-1,-1), 0),
+                ])
         self.style = style
         self.t = None
         self.repeatrows = repeatrows
@@ -741,8 +748,8 @@ class BoundByWidth(Flowable):
         if len(self.content) == 1:
             # We need to split the only element we have
             content = content[0].split(
-                (1./self.scale) * (availWidth - (self.pad[1]+self.pad[3])),
-                (1./self.scale) * (availHeight - (self.pad[0]+self.pad[2])))
+                availWidth - (self.pad[1]+self.pad[3]),
+                availHeight - (self.pad[0]+self.pad[2]))
         result =  [BoundByWidth(self.maxWidth, [f],
                              self.style, self.mode, self.scale) for f in content]
         return result
