@@ -1,8 +1,8 @@
 # -*- coding: utf-8 -*-
 
-#$URL: https://rst2pdf.googlecode.com/svn/tags/0.92/rst2pdf/genelements.py $
-#$Date: 2012-05-25 23:11:53 -0300 (Fri, 25 May 2012) $
-#$Revision: 2503 $
+#$URL: https://rst2pdf.googlecode.com/svn/tags/0.93/rst2pdf/genelements.py $
+#$Date: 2012-12-13 21:39:59 -0300 (Thu, 13 Dec 2012) $
+#$Revision: 2615 $
 
 # See LICENSE.txt for licensing terms
 
@@ -687,13 +687,26 @@ class HandleLineBlock(NodeHandler, docutils.nodes.line_block):
             qstyle = copy(client.styles['lineblock'])
         # Fix Issue 225: no space betwen line in a lineblock, but keep
         # space before the lineblock itself
-        return [MySpacer(0,client.styles['lineblock'].spaceBefore)]+client.gather_elements(node, style=qstyle)+[MySpacer(0,client.styles['lineblock'].spaceAfter)]
+        # Fix Issue 482: nested lineblocks don't need spacing before/after
+        if not isinstance(node.parent, docutils.nodes.line_block):
+            return [MySpacer(0,client.styles['lineblock'].spaceBefore)]+client.gather_elements(node, style=qstyle)+[MySpacer(0,client.styles['lineblock'].spaceAfter)]
+        else:
+            return client.gather_elements(node, style=qstyle)
 
 class HandleLine(NodeHandler, docutils.nodes.line):
     def gather_elements(self, client, node, style):
+        # line nodes have no classes, they have to inherit from the outermost lineblock (sigh)
+        # For more info see Issue 471 and its test case.
+        
+        parent = node
+        while isinstance(parent.parent, (docutils.nodes.line, docutils.nodes.line_block)):
+            parent=parent.parent
+        p_class = (parent.get('classes') or  ['line'])[0]
+        print node, p_class
+        qstyle = copy(client.styles[p_class])
         # Indent .5em per indent unit
         i=node.__dict__.get('indent',0)
-        qstyle = copy(client.styles['line'])
+        #qstyle = copy(client.styles['line'])
         qstyle.leftIndent += client.styles.adjustUnits("0.5em")*i
         text = client.gather_pdftext(node)
         if not text: # empty line
@@ -718,8 +731,10 @@ class HandleFigure(NodeHandler, docutils.nodes.figure):
 
         # Either use the figure style or the class
         # selected by the user
+        st_name = 'figure'
         if node.get('classes'):
-            style=client.styles[node.get('classes')[0]]
+            st_name = node.get('classes')[0]
+        style=client.styles[st_name]
         cmd=getattr(style,'commands',[])
         image=node.children[0]
         if len(node.children) > 1:
@@ -739,7 +754,8 @@ class HandleFigure(NodeHandler, docutils.nodes.figure):
         table = DelayedTable([[e,] for e in sub_elems],style=t_style,
             colWidths=cw)
         table.hAlign = node.get('align','CENTER').upper()
-        return [table]
+        return [MySpacer(0, style.spaceBefore),table,
+            MySpacer(0, style.spaceAfter)]
 
 
 class HandleCaption(NodeHandler, docutils.nodes.caption):
@@ -762,7 +778,7 @@ class HandleRubric(NodeHandler, docutils.nodes.rubric):
         # Sphinx uses a rubric as footnote container
         if self.sphinxmode and len(node.children) == 1 \
             and node.children[0].astext() == 'Footnotes':
-                return [Separation(),]
+                return []
         else:
             return [Paragraph(client.gather_pdftext(node),
                                 client.styles['rubric'])]
