@@ -13,7 +13,7 @@ import urllib
 
 from opt_imports import LazyImports
 
-from svgimage import SVGImage, VectorImage
+from svgimage import SVGImage
 
 # This assignment could be overridden by an extension module
 VectorPdf = None
@@ -71,7 +71,7 @@ class MyImage (Flowable):
         return fname, extension, options
 
     def __init__(self, filename, width=None, height=None,
-                 kind='direct', mask="auto", lazy=1, client=None):
+                 kind='direct', mask="auto", lazy=1, client=None, target=None):
         # Client is mandatory.  Perhaps move it farther up if we refactor
         assert client is not None
         self.__kind=kind
@@ -99,6 +99,7 @@ class MyImage (Flowable):
                 kind, mask, lazy, srcinfo)
         self.__ratio=float(self.image.imageWidth)/self.image.imageHeight
         self.__wrappedonce=False
+        self.target = target
 
     @classmethod
     def raster(self, filename, client):
@@ -246,11 +247,6 @@ class MyImage (Flowable):
             else:
                 filename = missing
 
-        elif extension in ['ai', 'ccx', 'cdr', 'cgm', 'cmx', 'fig',
-                'sk1', 'sk', 'xml', 'wmf']:
-            log.info('Backend for %s is VectorImage'%filename)
-            backend=VectorImage
-
         elif extension in ['pdf']:
             if VectorPdf is not None and filename is not missing:
                 backend = VectorPdf
@@ -269,7 +265,7 @@ class MyImage (Flowable):
         elif extension != 'jpg' and not LazyImports.PILImage:
             if LazyImports.PMImage:
                 # Need to convert to JPG via PythonMagick
-                filename=self.raster(filename)
+                filename=self.raster(filename, client)
             else:
                 # No way to make this work
                 log.error('To use a %s image you need PIL installed [%s]',extension,filename)
@@ -318,17 +314,10 @@ class MyImage (Flowable):
             iw = iw * xdpi / 72
             ih = ih * ydpi / 72
 
-        elif extension in [
-                "ai", "ccx", "cdr", "cgm", "cmx",
-                "sk1", "sk", "xml", "wmf", "fig"] and VectorImage.available():
-            iw, ih = VectorImage(imgname, srcinfo=srcinfo).wrap(0, 0)
-            # These are in pt, so convert to px
-            iw = iw * xdpi / 72
-            ih = ih * ydpi / 72
-
         elif extension == 'pdf':
             if VectorPdf is not None:
-                box = VectorPdf.load_xobj(srcinfo).BBox
+                xobj = VectorPdf.load_xobj(srcinfo)
+                iw, ih = xobj.w, xobj.h
             else:
                 pdf = LazyImports.pdfinfo
                 if pdf is None:
@@ -336,10 +325,10 @@ class MyImage (Flowable):
                     return 0, 0, 'direct'
                 reader = pdf.PdfFileReader(open(imgname, 'rb'))
                 box = [float(x) for x in reader.getPage(0)['/MediaBox']]
-            x1, y1, x2, y2 = box
+                iw, ih = x2 - x1, y2 - y1
             # These are in pt, so convert to px
-            iw = float((x2-x1) * xdpi / 72)
-            ih = float((y2-y1) * ydpi / 72)
+            iw = iw * xdpi / 72.0
+            ih = ih * ydpi / 72.0
             size_known = True  # Assume size from original PDF is OK
 
         else:
@@ -439,6 +428,9 @@ class MyImage (Flowable):
     def _restrictSize(self,aW,aH):
         return self.image._restrictSize(aW, aH)
 
+    def _unRestrictSize(self,aW,aH):
+        return self.image._unRestrictSize(aW, aH)
+
     def __deepcopy__(self, *whatever):
         # ImageCore class is not deep copyable.  Stop the copy at this
         # class.  If you remove this, re-test for issue #126.
@@ -479,5 +471,18 @@ class MyImage (Flowable):
             return self.image.wrap(availWidth, availHeight)
 
     def drawOn(self, canv, x, y, _sW=0):
+        if self.target:
+            offset = 0
+            if self.image.hAlign == 'CENTER':
+                offset = _sW / 2.
+            elif self.image.hAlign == 'RIGHT':
+                offset = _sW
+            canv.linkURL(self.target,
+                    (
+                    x + offset, y,
+                    x + offset + self.image.drawWidth, 
+                    y + self.image.drawHeight),
+                    relative = True,
+                    #thickness = 3,
+                    )
         return self.image.drawOn(canv, x, y, _sW)
-
