@@ -1,10 +1,10 @@
 # -*- coding: utf-8 -*-
-#$URL: https://rst2pdf.googlecode.com/svn/tags/0.92/rst2pdf/pygments_code_block_directive.py $
-#$Date: 2012-02-28 21:07:21 -0300 (Tue, 28 Feb 2012) $
-#$Revision: 2443 $
+#$URL: https://rst2pdf.googlecode.com/svn/tags/0.93/rst2pdf/pygments_code_block_directive.py $
+#$Date: 2012-12-08 12:17:31 -0300 (Sat, 08 Dec 2012) $
+#$Revision: 2591 $
 
 # :Author: a Pygments author|contributor; Felix Wiemann; Guenter Milde
-# :Date: $Date: 2012-02-28 21:07:21 -0300 (Tue, 28 Feb 2012) $
+# :Date: $Date: 2012-12-08 12:17:31 -0300 (Sat, 08 Dec 2012) $
 # :Copyright: This module has been placed in the public domain.
 #
 # This is a merge of `Using Pygments in ReST documents`_ from the pygments_
@@ -164,6 +164,20 @@ def code_block_directive(name, arguments, options, content, lineno,
                 if after_index < 0:
                     raise state_machine.reporter.severe('Problem with "start-at" option of "%s" '
                                       'code-block directive:\nText not found.' % options['start-at'])
+                # patch mmueller start
+                # Move the after_index to the beginning of the line with the
+                # match.
+                for char in content[after_index:0:-1]:
+                    # codecs always opens binary. This works with '\n', '\r' and
+                    # '\r\n'. We are going backwards, so '\n' is found first
+                    # in '\r\n'.
+                    # Going with .splitlines() seems more appropriate
+                    # but needs a few more changes.
+                    if char == u'\n' or char == u'\r':
+                        break
+                    after_index -= 1
+                # patch mmueller end
+
                 content = content[after_index:]
                 line_offset = len(content[:after_index].splitlines())
 
